@@ -25,6 +25,7 @@ def create_dataset(tfrecords,
                    depth,
                    seed,
                    batch_size,
+                   compression_type=None,
                    prefetching=True,
                    cache=True,
                    key="image_raw"):
@@ -43,6 +44,7 @@ def create_dataset(tfrecords,
         tfrecords file
     """
     raw_dataset = tf.data.TFRecordDataset(tfrecords,
+                                          compression_type,
                                           buffer_size=None,
                                           num_parallel_reads=num_parallel_reads)
 
