@@ -22,11 +22,13 @@ import tensorflow as tf
 def create_dataset(tfrecords,
                    buffer_size,
                    num_parallel_reads,
-                   depth,
+                   depth_source,
+                   depth_target,
                    seed,
                    batch_size,
                    keys,
                    encoding=True,
+                   compression_type=None,
                    prefetching=True,
                    cache=True):
     """Creates an optimized tf.data.Dataset object from a tfrecords file.
@@ -44,17 +46,20 @@ def create_dataset(tfrecords,
         tfrecords file
     """
     raw_dataset = tf.data.TFRecordDataset(tfrecords,
+                                          compression_type,
                                           buffer_size=None,
                                           num_parallel_reads=num_parallel_reads)
 
     # pre-processing function but apply it in parallel on multiple samples.
     if encoding:
         parsed_dataset = raw_dataset.map(
-            lambda example: _parse_tfrecords_encoded(example, depth, keys),
+            lambda example: _parse_tfrecords_encoded(example, depth_source,
+                                                     depth_target, keys),
             num_parallel_calls=tf.data.experimental.AUTOTUNE)
     else:
         parsed_dataset = raw_dataset.map(
-            lambda example: _parse_tfrecords_raw(example, depth, keys),
+            lambda example: _parse_tfrecords_raw(example, depth_source,
+                                                 depth_target, keys),
             num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
     parsed_dataset = parsed_dataset.shuffle(buffer_size, seed=seed)
@@ -69,7 +74,7 @@ def create_dataset(tfrecords,
     return parsed_dataset
 
 
-def _parse_tfrecords_encoded(example, depth, keys):
+def _parse_tfrecords_encoded(example, depth_source, depth_target, keys):
     # Create a dictionary describing the features.
     feature_description = {
         keys[0]: tf.io.FixedLenFeature([], tf.string, default_value=""),
@@ -80,18 +85,18 @@ def _parse_tfrecords_encoded(example, depth, keys):
     example = tf.io.parse_single_example(example, feature_description)
     img_source = example[keys[0]]
     # Convert encoded jpeg bytes into tensors. TODO decode_image
-    img_source = tf.io.decode_jpeg(img_source, channels=depth)
+    img_source = tf.io.decode_jpeg(img_source, channels=depth_source)
     img_source = tf.cast(img_source, tf.float32)
 
     img_target = example[keys[1]]
     # Convert encoded jpeg bytes into tensors.
-    img_target = tf.io.decode_jpeg(img_target, channels=depth)
+    img_target = tf.io.decode_jpeg(img_target, channels=depth_target)
     img_target = tf.cast(img_target, tf.float32)
 
     return img_source, img_target
 
 
-def _parse_tfrecords_raw(example, depth, keys):
+def _parse_tfrecords_raw(example, depth_source, depth_target, keys):
     # Create a dictionary describing the features.
     feature_description = {
         keys[0]: tf.io.FixedLenFeature([], tf.string, default_value=""),
@@ -118,12 +123,9 @@ def _parse_tfrecords_raw(example, depth, keys):
     # Restore spatial resolution of images.
     height_orig = tf.cast(example['height'], tf.int32)
     width_orig = tf.cast(example['width'], tf.int32)
-    # Defaults to grayscale if feature is missing in example. Doesnt work TODO
-    # depth = tf.cast(example['depth'], tf.int32)
-    depth_orig = depth
 
-    image_shape = tf.stack([height_orig, width_orig, depth_orig])
-    label_shape = tf.stack([height_orig, width_orig, depth_orig])
+    image_shape = tf.stack([height_orig, width_orig, depth_source])
+    label_shape = tf.stack([height_orig, width_orig, depth_target])
 
     img_source = tf.reshape(img_source, image_shape)
     img_target = tf.reshape(img_target, label_shape)
