@@ -31,6 +31,7 @@ def create_dataset(tfrecords,
                    seed,
                    batch_size,
                    key="image/encoded",
+                   compression_type=None,
                    prefetching=True,
                    cache=True):
     """Creates an optimized tf.data.Dataset object from a tfrecords file.
@@ -48,7 +49,7 @@ def create_dataset(tfrecords,
         tfrecords file
     """
     raw_dataset = tf.data.TFRecordDataset(
-        tfrecords, buffer_size=None, num_parallel_reads=num_parallel_reads)
+        tfrecords, compression_type, buffer_size=None, num_parallel_reads=num_parallel_reads)
 
     # pre-processing function but apply it in parallel on multiple samples.
     parsed_dataset = raw_dataset.map(
